@@ -39,7 +39,7 @@
 
 //@line 45 "/buildbot/linux_build/build/mail/app/profile/all-thunderbird.js"
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/3.0");
+pref("general.useragent.extra.thunderbird", "Thunderbird/3.0.1");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
